ca_procrustes: Correspondence Analysis with Procrustes Fitting

View source: R/procrustes.R

ca_procrustesR Documentation

Correspondence Analysis with Procrustes Fitting

Description

Fit scores of correspondence analysi on an incidence matrix to those produced by reference matrix which contain an ideal seriation using a Procrustes method (on the reference matrix, see im_ref). Rotation is determined by minimizing Euclidean distance from each row score to the nearest reference row score. Correspondence analysis is performed using the ca package \insertCitenenadic_correspondence_2007lakhesis.

Usage

ca_procrustes(obj, symmetric = TRUE)

## S3 method for class 'matrix'
ca_procrustes(obj, symmetric = TRUE)

## S3 method for class 'incidence_matrix'
ca_procrustes(obj, symmetric = TRUE)

Arguments

obj

An incidence matrix of size n x k.

symmetric

Whether to use standard scores for both rows and columns. Default is TRUE. Setting this to FALSE will result in a asymmetric map of standard scores for rows and principal scores for columns.

Value

A list object of class strand containing the following:

  • ref The Procrustes-fit coordinates of the scores of the reference seriation.

  • x The coordinates of the row standard scores of the data.

  • y The coordinates of the column principal scores of the data.

  • x_pr The Procrustes-fit coordinates of the row standard scores of the data.

  • y_pr The Procrustes-fit coordinates of the column column scores of the data.

References

\insertAllCited

Examples

data("quattrofontanili")
s <- ca_procrustes(quattrofontanili)
# print(s)


lakhesis documentation built on April 25, 2026, 5:06 p.m.