ca_procrustes_ser: Seriate Procrustes-Fit CA Scores

View source: R/procrustes.R

ca_procrustes_serR Documentation

Seriate Procrustes-Fit CA Scores

Description

Obtain a ranking of row and column scores projected onto a reference curve of an ideal seriation (row and column scores are ranked separately). Scores of correspondence analysis have been fit to those produced by reference matrix contain an ideal seriation using a Procrustes method, projecting them. Rotation is determined by minimizing Euclidean distance from each row score to the nearest reference row score. Correspondence analysis is performed using the ca package \insertCitenenadic_correspondence_2007lakhesis.

Usage

ca_procrustes_ser(obj, projection = "curve", samples = 10^5, symmetric = TRUE)

## S3 method for class 'incidence_matrix'
ca_procrustes_ser(obj, projection = "curve", samples = 10^5, symmetric = TRUE)

## S3 method for class 'matrix'
ca_procrustes_ser(obj, projection = "curve", samples = 10^5, symmetric = TRUE)

Arguments

obj

An incidence matrix of size n x k.

projection

Which projection to use:

  • ca1 The first axis for CA scores.

  • ca2 The second axis for CA scores.

  • procrustes1 The first axis of Procrustes-fit CA scores.

  • procrustes2 The second axis of Procrustes-fit CA scores.

  • curve The reference curve of an ideal seriation, using Procrustes fitting (this is the default).

samples

Number of samples to use for plotting points along polynomial curve. Default is 10^5.

symmetric

Whether to use standard scores for both rows and columns. Default is TRUE. Setting this to FALSE will result in a asymmetric map of standard scores for rows and principal scores for columns.

Value

A list of class strand containing the following:.

  • $dat A data frame with the following columns:

    • Procrustes1, Procrustes2 The location of the point on the biplot after fitting.

    • CurveIndex The orthogonal projection of the point onto the reference curve, given as the index of the point sampled along y = \beta_2 x^2 + \beta_0.

    • Distance The squared Euclidean distance of the point to the nearest point on the reference curve.

    • Rank The ranking of the row or column, a range of ⁠1:nrow`` and ⁠1:ncol“.

    • Type Either row or col.

    • sel Data frame column used in shiny app to indicate whether point is selected in biplot/curve projection.

  • $im_seriated The seriated incidence matrix, of class incidence_matrix.

References

\insertAllCited

Examples

data("quattrofontanili")
s <- ca_procrustes_ser(quattrofontanili)
# print(s)
# summary(s)


lakhesis documentation built on April 25, 2026, 5:06 p.m.