conc_c: Optimality Criterion: Kendall-Doran (Column) Concentration

View source: R/criterion.R

conc_cR Documentation

Optimality Criterion: Kendall-Doran (Column) Concentration

Description

The Kendall-Doran measure of concentration \insertCitekendall_statistical_1963,doran_computer_1971lakhesis. In a seriated matrix, this function computes the total number cells between the first and last non-zero value, column by column.

Usage

conc_c(obj)

## S3 method for class 'matrix'
conc_c(obj)

## S3 method for class 'incidence_matrix'
conc_c(obj)

Arguments

obj

A seriated binary matrix.

Value

The measure of concentration.

References

\insertAllCited

Examples

data("quattrofontanili")
conc_c(quattrofontanili)


lakhesis documentation built on April 25, 2026, 5:06 p.m.