conc_wrc: Optimality Criterion: Weighted Row-Column Concentration

View source: R/criterion.R

conc_wrcR Documentation

Optimality Criterion: Weighted Row-Column Concentration

Description

Extends the Kendall-Doran (column) measure of concentration (see conc_c) to include rows and then weights the total measure by the total sum of values in the matrix.

Usage

conc_wrc(obj)

## S3 method for class 'matrix'
conc_wrc(obj)

## S3 method for class 'incidence_matrix'
conc_wrc(obj)

Arguments

obj

A seriated binary matrix.

Value

The weighted row-column coefficient of concentration.

Examples

data("quattrofontanili")
conc_wrc(quattrofontanili)


lakhesis documentation built on April 25, 2026, 5:06 p.m.