lakhesize: Lakhesize

View source: R/lakhesize.R

lakhesizeR Documentation

Lakhesize

Description

This function returns the row and column consensus seriation for a list object of the strands class, containing their rankings, coefficients of association, and criterion. Consensus seriation is achieved by iterative simple linear regression to handle NA vales in each strand. To initialize, a regression is performed pairwise, with every strand as the dependent y variate and every other strand as the independent x variate. The independent variate's rankings are then regressed onto f(x) = \hat{\beta}_1 x + \hat{\beta}_0. If y \neq f(x), the mean of y and f(x) is used. Then, the values of the dependent variate and those of the regressed independent varaite are re-ranked together, to form a combined ranking, which serves as the dependent variate on the next iteration. The pair of strands is chosen which minimizes a specified optimality criterion. The process is repeated until all strands have been regressed and re-ranked into a single consensus seriation.

Usage

lakhesize(strands, crit = "cor_sq", pbar = TRUE)

## S3 method for class 'strands'
lakhesize(strands, crit = "cor_sq", pbar = TRUE)

## Default S3 method:
lakhesize(strands, crit = "cor_sq", pbar = TRUE)

Arguments

strands

A list of strands class (see strand_add).

crit

The criterion used to assess the seration resulting from two strands x and y:

  • "cor_sq" Computes a squared correlation coefficent for the incidences of 1s as points (i,j). See cor_sq. Higher values are more optimal. This is the default option.

  • "conc_wrc" Computes weighted row-column concentration as the optimality criterion. See conc_wrc. Lower values are more optimal.

pbar

Displaying a progress bar. Default is TRUE.

Value

A list of class lakhesis containing the following:

  • row A seriated vector of row elements.

  • col A seriated vector of column elements

  • coef A data frame containing the following columns:

    • Strand The number of the strand.

    • Agreement The measure of agreement, i.e., how well each strand accords with the consensus seriation. Using the square of Spearman's rank correlation coefficient, \rho^2, between each strand and the consensus ranking, agreement is computed as the product of \rho^2 for their row and column rankings, \rho_r^2\rho_c^2.

    • Criterion Criterion of the optimality of each strand (per the "crit" option above).

  • im_seriated The seriated incidence matrix, of class incidence_matrix.

Examples

data("qf_strands")
L <- lakhesize(qf_strands, pbar = FALSE)
# summary(L) 


lakhesis documentation built on April 25, 2026, 5:06 p.m.