qf_strands: Quattro Fontanili - Strands

qf_strandsR Documentation

Quattro Fontanili - Strands

Description

Three seriated strands selected from quattrofontanili data, identified by the package author as an example for the documentation of functions.

Usage

data("qf_strands")

Format

A strands object containing strands output by ca_procrustes.

Examples

data("qf_strands")
print(qf_strands)


lakhesis documentation built on April 25, 2026, 5:06 p.m.