strand_add: Add Strand to List of Strands

View source: R/strand.R

strand_addR Documentation

Add Strand to List of Strands

Description

Given a list of strands, remove a row or column element and re-run seriation by correspondence analysis with Procrustes fitting (ca_procrustes_ser) to generate a new list of strands that exclude the specified elements. If the resulting strand lacks sufficient points to perform correspondence analysis, that strand is deleted in the output.

Usage

strand_add(strand, strands)

## S3 method for class 'strand'
strand_add(strand, strands)

Arguments

strand

An object of class strand returned by ca_procrustes_ser.

strands

A list of strands.

Value

A list of class strands.


lakhesis documentation built on April 25, 2026, 5:06 p.m.