strand_extract: Strand Extract

View source: R/strand.R

strand_extractR Documentation

Strand Extract

Description

From a list of strands produced by ca_procrustes_ser, extract two matrices containing the ranks of the rows and columns. The row/column elements are contained in the rows, and the strands are contained in the columns. NA values are entered where a given row/column element is missing from that strand.

Usage

strand_extract(strands)

Arguments

strands

A list of class strands.

Value

A list of two matrices:

  • Row A matrix of the ranks of the row elements.

  • Col A matrix of the ranks of the column elements.

Examples

data("quattrofontanili")
data("qf_strands")
strand_extract(qf_strands)


lakhesis documentation built on April 25, 2026, 5:06 p.m.