| LC | R Documentation |
Launch Lakhesis Calculator, a graphical interface to explore binary matrices via correspondence analysis, select potentially well-seriated sequences, and perform consensus seriation. Interface is made with ggplot2, shiny, shinydashboard, and bslib \insertCitewickham_ggplot2:_2016,chang_shiny_2024,chang_shinydashboard_2021,sievert_bslib_2024lakhesis.
LC()
Input is done in the calculator, via a "long" format a two-column .csv file giving pairs of row and column incidences. See im_read_csv for details. Conversion of a pre-existing incidence matrix to long format can be performed with im_long.
Results can be downloaded from the calculator as an .rds file containing a list of the following:
consensus The consensus seriations, diagnostic coefficients of agreement and optimality criterion, and seriated incidence matrix.
(lakhesize).
strands The strands selected by the investigator.
Opens the Lakhesis Calculator.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.