| ca_procrustes | R Documentation |
Fit scores of correspondence analysi on an incidence matrix to those produced by reference matrix which contain an ideal seriation using a Procrustes method (on the reference matrix, see im_ref). Rotation is determined by minimizing Euclidean distance from each row score to the nearest reference row score. Correspondence analysis is performed using the ca package \insertCitenenadic_correspondence_2007lakhesis.
ca_procrustes(obj, symmetric = TRUE)
## S3 method for class 'matrix'
ca_procrustes(obj, symmetric = TRUE)
## S3 method for class 'incidence_matrix'
ca_procrustes(obj, symmetric = TRUE)
obj |
An incidence matrix of size n x k. |
symmetric |
Whether to use standard scores for both rows and columns. Default is |
A list object of class strand containing the following:
ref The Procrustes-fit coordinates of the scores of the reference seriation.
x The coordinates of the row standard scores of the data.
y The coordinates of the column principal scores of the data.
x_pr The Procrustes-fit coordinates of the row standard scores of the data.
y_pr The Procrustes-fit coordinates of the column column scores of the data.
data("quattrofontanili")
s <- ca_procrustes(quattrofontanili)
# print(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.