| conc_c | R Documentation |
The Kendall-Doran measure of concentration \insertCitekendall_statistical_1963,doran_computer_1971lakhesis. In a seriated matrix, this function computes the total number cells between the first and last non-zero value, column by column.
conc_c(obj)
## S3 method for class 'matrix'
conc_c(obj)
## S3 method for class 'incidence_matrix'
conc_c(obj)
obj |
A seriated binary matrix. |
The measure of concentration.
data("quattrofontanili")
conc_c(quattrofontanili)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.