| conc_wrc | R Documentation |
Extends the Kendall-Doran (column) measure of concentration (see conc_c) to include rows and then weights the total measure by the total sum of values in the matrix.
conc_wrc(obj)
## S3 method for class 'matrix'
conc_wrc(obj)
## S3 method for class 'incidence_matrix'
conc_wrc(obj)
obj |
A seriated binary matrix. |
The weighted row-column coefficient of concentration.
data("quattrofontanili")
conc_wrc(quattrofontanili)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.