| element_eval | R Documentation |
Performs a goodness-of-fit test on individual row and column elements using deviance, using a quadratic-logistic model to fit row and column occurrences. In the case of perfect separation of 0/1 values, an NA value is assigned. Results are reported as p values for each row and column.
element_eval(obj)
## S3 method for class 'matrix'
element_eval(obj)
## S3 method for class 'incidence_matrix'
element_eval(obj)
obj |
A seriated binary matrix. |
A list containing results in data frames for row and column elements:
RowFit a data frame containing
id Row element
p.val p values of the row elements
ColFit a data frame containing
id Column element
p.val p values of the column elements
data("quattrofontanili")
element_eval(quattrofontanili)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.