| lakhesize | R Documentation |
This function returns the row and column consensus seriation for a list object of the strands class, containing their rankings, coefficients of association, and criterion. Consensus seriation is achieved by iterative simple linear regression to handle NA vales in each strand. To initialize, a regression is performed pairwise, with every strand as the dependent y variate and every other strand as the independent x variate. The independent variate's rankings are then regressed onto f(x) = \hat{\beta}_1 x + \hat{\beta}_0. If y \neq f(x), the mean of y and f(x) is used. Then, the values of the dependent variate and those of the regressed independent varaite are re-ranked together, to form a combined ranking, which serves as the dependent variate on the next iteration. The pair of strands is chosen which minimizes a specified optimality criterion. The process is repeated until all strands have been regressed and re-ranked into a single consensus seriation.
lakhesize(strands, crit = "cor_sq", pbar = TRUE)
## S3 method for class 'strands'
lakhesize(strands, crit = "cor_sq", pbar = TRUE)
## Default S3 method:
lakhesize(strands, crit = "cor_sq", pbar = TRUE)
strands |
A |
crit |
The criterion used to assess the seration resulting from two strands
|
pbar |
Displaying a progress bar. Default is |
A list of class lakhesis containing the following:
row A seriated vector of row elements.
col A seriated vector of column elements
coef A data frame containing the following columns:
Strand The number of the strand.
Agreement The measure of agreement, i.e., how well each strand accords with the consensus seriation. Using the square of Spearman's rank correlation coefficient, \rho^2, between each strand and the consensus ranking, agreement is computed as the product of \rho^2 for their row and column rankings, \rho_r^2\rho_c^2.
Criterion Criterion of the optimality of each strand (per the "crit" option above).
im_seriated The seriated incidence matrix, of class incidence_matrix.
data("qf_strands")
L <- lakhesize(qf_strands, pbar = FALSE)
# summary(L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.