| qf_strands | R Documentation |
Three seriated strands selected from quattrofontanili data, identified by the package author as an example for the documentation of functions.
data("qf_strands")
A strands object containing strands output by ca_procrustes.
data("qf_strands")
print(qf_strands)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.