| strand_add | R Documentation |
Given a list of strands, remove a row or column element and re-run seriation by correspondence analysis with Procrustes fitting (ca_procrustes_ser) to generate a new list of strands that exclude the specified elements. If the resulting strand lacks sufficient points to perform correspondence analysis, that strand is deleted in the output.
strand_add(strand, strands)
## S3 method for class 'strand'
strand_add(strand, strands)
strand |
An object of class |
strands |
A |
A list of class strands.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.