| strand_extract | R Documentation |
From a list of strands produced by ca_procrustes_ser, extract two matrices containing the ranks of the rows and columns. The row/column elements are contained in the rows, and the strands are contained in the columns. NA values are entered where a given row/column element is missing from that strand.
strand_extract(strands)
strands |
A |
A list of two matrices:
Row A matrix of the ranks of the row elements.
Col A matrix of the ranks of the column elements.
data("quattrofontanili")
data("qf_strands")
strand_extract(qf_strands)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.