| strand_suppress | R Documentation |
Given a list of strands produced by correspondence analysis with Procrustes fitting (ca_procrustes_ser), remove one or more row or column elements, re-seriating each strand. This generates a new list of strands that exclude the specified elements. If a resulting strand lacks sufficient points to perform correspondence analysis, that strand is deleted in the output.
strand_suppress(strands, elements)
## S3 method for class 'strands'
strand_suppress(strands, elements)
## Default S3 method:
strand_suppress(strands, elements)
strands |
A |
elements |
A vector of one or more row or column ids to suppress. |
A list of the strands.
data("qf_strands")
strand_suppress(qf_strands, "QF II 15-16")
strand_suppress(qf_strands, c("QF II 15-16", "I", "XIV"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.